Converter class

A converter class that provides methods to convert string values to their appropriate types (null, boolean, number, or string).

Constructors

Converter()
A constant constructor for the Converter class, allowing it to be used as a compile-time constant.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

convertValue(Object? value) Object?
Converts a string value to its appropriate type (null, boolean, number, or string).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited